==> beast-cart-api-2.0.2-20200113.085234-10-sources.jar: com/thebeastshop/cart/model/ScCartBenefit.java <==
package com.thebeastshop.cart.model;

import com.thebeastshop.common.BaseDO;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author feiLong.gao
 * @date 2019/12/25
 */
public class ScCartBenefit extends BaseDO {


    /**
     * 权益id
     */
    private String id;
    /**
     * 权益兑换开始时间
     */
    private Date cashStartTime;

    /**
     * 是否有门槛
     */
    private Boolean isThreshold = true;

    /**
     * 门槛金额
     */
    private BigDecimal thresholdPrice;
    /**
     * 权益兑换结束时间
     */
    private Date cashEndTime;

    /**
     * 抵扣金额
     */
    private BigDecimal deductionPrice;

    /**
     * 是否定金权益
     */
    private Boolean deposit = Boolean.FALSE;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Date getCashStartTime() {
        return cashStartTime;
    }

    public void setCashStartTime(Date cashStartTime) {
        this.cashStartTime = cashStartTime;
    }

    public Boolean getIsThreshold() {
        return isThreshold;
    }

    public void setIsThreshold(Boolean isThreshold) {
        this.isThreshold = isThreshold;
    }

    public BigDecimal getThresholdPrice() {
        return thresholdPrice;
    }

    public void setThresholdPrice(BigDecimal thresholdPrice) {
        this.thresholdPrice = thresholdPrice;
    }

    public Date getCashEndTime() {
        return cashEndTime;
    }

    public void setCashEndTime(Date cashEndTime) {
        this.cashEndTime = cashEndTime;
    }

    public BigDecimal getDeductionPrice() {
        return deductionPrice;
    }

    public void setDeductionPrice(BigDecimal deductionPrice) {
        this.deductionPrice = deductionPrice;
    }

    public Boolean getDeposit() {
        return deposit;
    }

    public void setDeposit(Boolean deposit) {
        this.deposit = deposit;
    }
}

==> beast-cart-api-2.0.9-sources.jar: com/thebeastshop/cart/model/ScCartBenefit.java <==
package com.thebeastshop.cart.model;

import com.thebeastshop.common.BaseDO;
import com.thebeastshop.common.enums.AccessWayEnum;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author feiLong.gao
 * @date 2019/12/25
 */
public class ScCartBenefit extends BaseDO {


    /**
     * 权益id
     */
    private String id;
    /**
     * 权益兑换开始时间
     */
    private Date cashStartTime;

    /**
     * 是否有门槛
     */
    private Boolean isThreshold = true;

    /**
     * 门槛金额
     */
    private BigDecimal thresholdPrice;
    /**
     * 权益兑换结束时间
     */
    private Date cashEndTime;

    /**
     * 抵扣金额
     */
    private BigDecimal deductionPrice;

    /**
     * 是否定金权益
     */
    private Boolean deposit = Boolean.FALSE;

    /**
     * 适用渠道，如果为空则表示全渠道可用
     */
    private List<AccessWayEnum> accessWayList;




    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Date getCashStartTime() {
        return cashStartTime;
    }

    public void setCashStartTime(Date cashStartTime) {
        this.cashStartTime = cashStartTime;
    }

    public Boolean getIsThreshold() {
        return isThreshold;
    }

    public void setIsThreshold(Boolean isThreshold) {
        this.isThreshold = isThreshold;
    }

    public BigDecimal getThresholdPrice() {
        return thresholdPrice;
    }

    public void setThresholdPrice(BigDecimal thresholdPrice) {
        this.thresholdPrice = thresholdPrice;
    }

    public Date getCashEndTime() {
        return cashEndTime;
    }

    public void setCashEndTime(Date cashEndTime) {
        this.cashEndTime = cashEndTime;
    }

    public BigDecimal getDeductionPrice() {
        return deductionPrice;
    }

    public void setDeductionPrice(BigDecimal deductionPrice) {
        this.deductionPrice = deductionPrice;
    }

    public Boolean getDeposit() {
        return deposit;
    }

    public void setDeposit(Boolean deposit) {
        this.deposit = deposit;
    }

    public List<AccessWayEnum> getAccessWayList() {
        return accessWayList;
    }

    public void setAccessWayList(List<AccessWayEnum> accessWayList) {
        this.accessWayList = accessWayList;
    }
}
